%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% IDENTIFICATION
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% path of this file and of the bibliography style file
%%% (if this command is undefined path is the current directory)
\providecommand{\filespath}{./}

\newcommand{\className}{afps-colloque}
\newcommand{\classVersion}{1}
\newcommand{\firstVersionDate}{13/05/2015}
\newcommand{\fileDate}{13/05/2015}
\newcommand{\docDate}{13/05/2015}

\NeedsTeXFormat{LaTeX2e}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% INITIAL CODE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{ifthen}

%%% booleans declaration (by default, false)
\newboolean{BOOL@cropmarksEnabled}
\newboolean{BOOL@toc}
\newboolean{BOOL@foreword}
%%% \newboolean{BOOL@editorModeEnabled}
\newboolean{BOOL@englishEnabled}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% DECLARATION OF OPTIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\DeclareOption{cropmarks}{%
   \typeout{\className.cls: ``cropmarks'' option enabled}%
   \setboolean{BOOL@cropmarksEnabled}{true}%
}

\DeclareOption{toc}{%
   \typeout{\className.cls: ``toc'' option enabled}%
   \setboolean{BOOL@toc}{true}%
}

\DeclareOption{foreword}{%
   \typeout{\className.cls: ``foreword'' option enabled}%
   \setboolean{BOOL@foreword}{true}%
}

\DeclareOption{francais}{%
   \typeout{\className.cls: ``english'' option enabled}%
   \setboolean{BOOL@englishEnabled}{true}%
}

\DeclareOption*{%
    \typeout{\className.cls WARNING: ``\CurrentOption'' option is unknown}
    \typeout{Valid options: cropmarks, editorMode, english}
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% EXECUTION OF OPTIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\ProcessOptions\relax

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% PACKAGE LOADING
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\LoadClass[10pt,twoside,a4paper]{article}

\RequirePackage[T1]{fontenc}
\RequirePackage[latin1]{inputenc}
\RequirePackage{amsmath}
\RequirePackage{amsfonts}
\RequirePackage{amssymb}
\RequirePackage{amsthm}  % must be loaded AFTER amsmath package
\RequirePackage{mathrsfs}                       % gives \mathscr
\RequirePackage{epsfig}
\RequirePackage{pifont}
% +BR
\RequirePackage{pst-all}
\RequirePackage{graphicx}
\RequirePackage{caption}
% -BR
\RequirePackage{url}
\RequirePackage{color}
\RequirePackage{xspace}
\RequirePackage{calc}
\RequirePackage{times}
\ifthenelse{\boolean{BOOL@englishEnabled}}%
{%  THEN
    \RequirePackage[english]{babel}%
}{% ELSE
    \RequirePackage[frenchb]{babel}%
    \NoAutoSpaceBeforeFDP
    \frenchbsetup{AutoSpacePunctuation=false}
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% MAIN CODE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%==============================================================
%==============================================================
% LAYOUT ======================================================
%==============================================================
%==============================================================


%==============================================================
% page layout =================================================
%==============================================================

% -------------------------------------------------------------
% horizontal margins
% -------------------------------------------------------------

\setlength{\voffset}{-1in}
\setlength{\oddsidemargin}{2.5cm}
\setlength{\evensidemargin}{2.5cm}
\setlength{\textwidth}{16cm}
\setlength{\marginparsep}{0cm}
\setlength{\marginparwidth}{0cm}
\setlength{\marginparpush}{0cm}

% -------------------------------------------------------------
% vertical margins
% -------------------------------------------------------------

\setlength{\hoffset}{-1in}
\setlength{\topmargin}{2.0cm}
\setlength{\headheight}{3.0cm}
\setlength{\headsep}{1.5cm}
\setlength{\textheight}{19.5cm}
\setlength{\footskip}{5.5cm}


%==============================================================
% crop marks ==================================================
%==============================================================

% if cropmarks option is enabled
\ifthenelse{\boolean{BOOL@cropmarksEnabled}}%
{%  THEN
    \setlength{\overfullrule}{12pt}
    \newcommand{\DRAW@cropMarks}{%
        \begingroup
            \thinlines%
            \setlength{\unitlength}{1mm}%
            % \@drawCropMarks will called from the bottom of header line
            % Distance between this point and the top of the first text line is \headsep
            % But length cannot be used as argument of the initial picture position
            % \headsep = 5.35cm - 4.4cm - 11/72.27in = 0.95cm - 11*25.4/72.27cm = 0.5634cm = 5.634mm
            \begin{picture}(0,0)%
            \put(0,-5.634){\line(1,0){120}}      % top side of the text
            \put(0,-195.634){\line(1,0){120}}    % bottom side of the text
            \put(0,-5.634){\line(0,-1){190}}     % left side of the text
            \put(120,-5.634){\line(0,-1){190}}   % right side of the text
            \end{picture}
        \endgroup}%
        % the following command add a margin mark when line is too long (overfull \hbox)
        \setlength{\overfullrule}{1pt}
}{% ELSE
    \setlength{\overfullrule}{0pt}
    \newcommand{\DRAW@cropMarks}{}%
}


%==============================================================
% headers and footers =========================================
%==============================================================
% normal issue
\newcommand{\ps@articleFirstPage}{%
    \renewcommand{\@oddhead}{\parbox{\textwidth}{\DRAW@cropMarks \WRITE@articleFreeColumn}}%
    \renewcommand{\@oddfoot}{\parbox{\textwidth}{\DRAW@cropMarks\hspace*{\fill}{\small 9$^{me}$ Colloque National AFPS 2015 - IFSTTAR, Marne-la-Valle}}}%
}

% normal issue
\newcommand{\ps@articleOtherpages}{%
    \renewcommand{\@evenhead}{\parbox{\textwidth}{\DRAW@cropMarks\hspace*{\fill}{\small 9$^{\text{\`e}me}$ Colloque National AFPS 2015 - IFSTTAR, Marne-la-Valle \ \ \ \ \ \thepage}}}%
    \renewcommand{\@oddhead}{\parbox{\textwidth}{\DRAW@cropMarks\hspace*{\fill}{\small 9$^{\text{\`e}me}$ Colloque National AFPS 2015 - IFSTTAR, Marne-la-Valle \ \ \ \ \ \thepage}}}%
}

%==============================================================
%==============================================================
% JOURNAL PARAMETERS ==========================================
%==============================================================
%==============================================================

%==============================================================
% journal abstract and keywords language(s) ===================
%==============================================================

%%% Some journal have both abstract and keywords only in english.
%%% For other journals, abstract and keywords
%%% are both in French and in English: in this case, the first abstract
%%% is in French if the article is written in French, and the first
%%% abstract is in English is the article language is English.

\newboolean{BOOL@journalLanguagesNumberDefined}

% must abstract and keywords be written both in English and in French,
% or must they be written only in English? (by default, two)
\newboolean{BOOL@journalInEnglishOnly}

\newcommand{\journalInEnglishOnly}{
    \ifthenelse{\not\boolean{BOOL@journalLanguagesNumberDefined}}%
    {%  THEN
        \setboolean{BOOL@journalInEnglishOnly}{true}
        \setboolean{BOOL@journalLanguagesNumberDefined}{true}
    }{% ELSE
        % nothing else
    }
}

\newcommand{\journalNotOnlyInEnglish}{
    \ifthenelse{\not\boolean{BOOL@journalLanguagesNumberDefined}}%
    {%  THEN
        \setboolean{BOOL@journalLanguagesNumberDefined}{true}
    }{% ELSE
        % nothing else
    }
}

%==============================================================
%==============================================================
% ARTICLE PARAMETERS ==========================================
%==============================================================
%==============================================================


%==============================================================
% article free column =========================================
%==============================================================

\newboolean{BOOL@articleFreeColumnDefined}

\newcommand{\freecolumn}[1]{
    \newcommand{\VAR@articleFreeColumn}{#1}
    \setboolean{BOOL@articleFreeColumnDefined}{true}
}

% -------------------------------------------------------------
% subtitle writing command used by \maketitle
% -------------------------------------------------------------

\newcommand{\WRITE@articleFreeColumn}{%
    \large\sc%
    \ifthenelse{\boolean{BOOL@articleFreeColumnDefined}}%
    {%  THEN
        \hspace*{\fill}\VAR@articleFreeColumn\hspace*{\fill}\par\smallskip\hrule
    }{% ELSE
        \hspace*{\fill}\strut\hspace*{\fill}\par\smallskip\hrule
    }
}


%==============================================================
% (short) article title =======================================
%==============================================================


\newcommand{\VAR@articleTitle}{!! Title undefined !!}
\newcommand{\VAR@articleShortTitle}{!! Short title undefined !!}

% -------------------------------------------------------------
% the author can specify the title of his article by the \title command
% [#1] is the short title (short title is used is the article header)
% #2 is the title
% -------------------------------------------------------------

\newboolean{BOOL@articleTitleDefined}

\renewcommand{\title}[2][NIL]{
    \renewcommand{\VAR@articleTitle}{#2}
    \ifthenelse{\equal{#1}{NIL}}%
    {%  THEN
        % a short title has not been specified
        % thus short title is the same as title
        \renewcommand{\VAR@articleShortTitle}{#2}
    }{% ELSE
        % a short title has been specified
        \renewcommand{\VAR@articleShortTitle}{#1}
    }
    \setboolean{BOOL@articleTitleDefined}{true}
}


% -------------------------------------------------------------
% title writing command used by \maketitle
% -------------------------------------------------------------

\newcommand{\WRITE@articleTitle}{%
    \begingroup
%        \setlength{\parindent}{0pt}
%        \setlength{\parskip}{0pt plus 1pt minus 1pt}
%        \setlength{\parsep}{0pt plus 1pt minus 1pt}
        \fontsize{18}{20}\bf\selectfont
        \begin{flushleft}
        \ifthenelse{\boolean{BOOL@articleTitleDefined}}%
        {%  THEN
%            \phantom{invisible line}
            \vspace{-1.5cm}
            \VAR@articleTitle%
        }{% ELSE
%            \phantom{invisible line}
            \textcolor{red}{!!!! Article title undefined !!!!}
        }
        \end{flushleft}
        % new empty line
        \vspace{\baselineskip}%
    \endgroup
}

% -------------------------------------------------------------
% short title writing command used by header
% -------------------------------------------------------------

\newsavebox{\BOX@shortTitleBox}

\newcommand{\WRITE@articleShortTitle}{%
    \begingroup
        \setlength{\parindent}{0pt}
        \setlength{\parsep}{0pt plus 1pt minus 1pt}
        \small
        \sbox{\BOX@shortTitleBox}{\small\VAR@articleShortTitle\ \ \ \ \ \thepage}
        % IF the short title is too long
        \ifthenelse{\lengthtest{\wd\BOX@shortTitleBox > 80mm}}%
        {%  THEN
            \textcolor{red}{\ \ \ \ \ !!!! Short title too long !!!!}
        }{% ELSE
            \VAR@articleShortTitle
        }
    \endgroup
}


%==============================================================
% article subtitle =========================================
%==============================================================

\newboolean{BOOL@articleSubTitleDefined}

\newcommand{\subtitle}[1]{
    \newcommand{\VAR@articleSubTitle}{#1}
    \setboolean{BOOL@articleSubTitleDefined}{true}
}

% -------------------------------------------------------------
% subtitle writing command used by \maketitle
% -------------------------------------------------------------

\newcommand{\WRITE@articleSubTitle}{%
    \begingroup
        \setlength{\parindent}{0pt}
        \setlength{\parskip}{0pt plus 1pt minus 1pt}
        \setlength{\parsep}{0pt plus 1pt minus 1pt}
        \par\Large\bf              % \fontsize{14}{16}\selectfont
        \ifthenelse{\boolean{BOOL@articleSubTitleDefined}}%
        {%  THEN
            \begin{flushleft}
            \VAR@articleSubTitle
            % new empty line
            {\fontsize{18}{20}\bf\selectfont\vspace{\baselineskip}}
            \end{flushleft}
        }{% ELSE
            % nothing (subtitle is not obligatory)
        }
    \endgroup
}


%==============================================================
% article authors list ========================================
%==============================================================

% -------------------------------------------------------------
% contains the authors number. The value 0 means that no author
% has been defined
% -------------------------------------------------------------

\newcounter{COUNT@articleAuthorNumber}
\setcounter{COUNT@articleAuthorNumber}{0}

% -------------------------------------------------------------
% this command must be called as many as authors number.
% [#1]: number relying author and address(es)
% #2: both first name and last name of the author
% Output: commands named \VAR@articleAuthorI, \VAR@articleAuthorII...
% containing respectively the first author, the second author...
% -------------------------------------------------------------

\renewcommand{\author}[3][NIL]{%
    \stepcounter{COUNT@articleAuthorNumber}%
    \expandafter\newcommand\csname VAR@articleAuthor\Roman{COUNT@articleAuthorNumber}\endcsname{\mbox{#2~#3}}%
    \ifthenelse{\equal{#1}{NIL}}%
    {%  THEN
        \expandafter\newcommand\csname VAR@articleAuthorInstituteNumber\Roman{COUNT@articleAuthorNumber}\endcsname{}
    }{% ELSE
        \expandafter\newcommand\csname VAR@articleAuthorInstituteNumber\Roman{COUNT@articleAuthorNumber}\endcsname{\textsuperscript{{\normalfont \,#1}}}
    }
    % we create a false author containing the delimiter between this author and the next one
    % we do the same for the institute numbering
    \stepcounter{COUNT@articleAuthorNumber}
    \expandafter\newcommand\csname VAR@articleAuthor\Roman{COUNT@articleAuthorNumber}\endcsname{,\ }%
    \expandafter\newcommand\csname VAR@articleAuthorInstituteNumber\Roman{COUNT@articleAuthorNumber}\endcsname{}%
}

% -------------------------------------------------------------
% introduces a newline after the name of an author
% -------------------------------------------------------------

%%% in fact, each author name is followed by a 'false' \VAR@articleAuthor
%%%  command that contains ', ' (for linking this author and the next one).
%%%  The following command just replace ', ' by \newline in the current
%%% \VAR@articleAuthor command that is given by the current value of
%%% COUNT@articleAuthorNumber

\newcommand{\andauthor}{%
    \expandafter\renewcommand\csname VAR@articleAuthor\Roman{COUNT@articleAuthorNumber}\endcsname{, \newline}
}


% -------------------------------------------------------------
% author list writing command used by \maketitle
% -------------------------------------------------------------

\newcommand{\WRITE@articleAuthors}{%
    \begingroup
        \setlength{\parindent}{0pt}%
        \setlength{\parsep}{0pt plus 1pt minus 1pt}%
        \setlength{\baselineskip}{0pt plus 1pt minus 1pt}%
        \large\bf%              \fontsize{12}{14}\selectfont
        \raggedright%
        \ifthenelse{\value{COUNT@articleAuthorNumber}>0}%
        {%  THEN
            % the last author name command correspond to
            % a ', ' string. Thus, we erase this value by nothing
            \expandafter\renewcommand\csname VAR@articleAuthor\Roman{COUNT@articleAuthorNumber}\endcsname{}%
            %
            % we write the first author
            \par\VAR@articleAuthorI%
            \VAR@articleAuthorInstituteNumberI%
            %
            % we write the others
            \newcounter{COUNT@cptAuthors}%
            \setcounter{COUNT@cptAuthors}{1}%
            \whiledo{\value{COUNT@cptAuthors} < \value{COUNT@articleAuthorNumber}}%
            {%  DO
                \stepcounter{COUNT@cptAuthors}%
                \csname VAR@articleAuthor\Roman{COUNT@cptAuthors}\endcsname%
                \csname VAR@articleAuthorInstituteNumber\Roman{COUNT@cptAuthors}\endcsname%
            }%  END DO
        }{% ELSE
            \par\textcolor{red}{!!! No author defined !!!!}%
        }
        % new empty line
        \fontsize{18}{20}\bf\selectfont\vspace{\baselineskip}
    \endgroup
}

%==============================================================
% article biographies list ======================================
%==============================================================

% -------------------------------------------------------------
% contains the biography number. The value 0 means that no biography
% has been defined
% -------------------------------------------------------------

\newcounter{COUNT@articleBiographyNumber}
\setcounter{COUNT@articleBiographyNumber}{0}

% -------------------------------------------------------------
% this command must be called as many times as authors number.
% Contrary to authors, biography is automatically numbered.
% #1: biography of an author
% Output: commands named \VAR@articleBiographyI, \VAR@articleBiographyII, \VAR@articleBiographyIII...
% containing respectively the biography of the first author, of the second author...
% -------------------------------------------------------------

\newcommand{\biography}[1]{%
    \stepcounter{COUNT@articleBiographyNumber}
    \expandafter\newcommand\csname VAR@articleBiography\Roman{COUNT@articleBiographyNumber}\endcsname{#1}
}


% -------------------------------------------------------------
% addresses list writing command used by \AtEndDocument
% -------------------------------------------------------------

\newcommand{\WRITE@articleBiographies}{%
    \par\bigskip\begingroup
        \setlength{\parindent}{0pt}
        \setlength{\parsep}{0pt plus 1pt minus 1pt}
        \setlength{\parskip}{0pt plus 1pt minus 1pt}
        \normalsize\em    % \fontsize{10}{12}\selectfont
        \raggedright
        \newcounter{COUNT@cptBiographies}
        \setcounter{COUNT@cptBiographies}{0}
        \newcounter{COUNT@authorNum}
        \setcounter{COUNT@authorNum}{0}%
        \ifthenelse{\value{COUNT@articleBiographyNumber}>0}%
        {%  THEN
            \whiledo{\(\value{COUNT@cptBiographies}<\value{COUNT@articleBiographyNumber}\) \and
                     \(\value{COUNT@authorNum}<\value{COUNT@articleAuthorNumber}\)}%
            {%  DO
                \stepcounter{COUNT@cptBiographies}%
                \stepcounter{COUNT@authorNum}%
                {\normalfont\small\csname VAR@articleAuthor\Roman{COUNT@authorNum}\endcsname.}
                {\normalfont\small\itshape\csname VAR@articleBiography\Roman{COUNT@cptBiographies}\endcsname}\\[6pt]
                \stepcounter{COUNT@authorNum}% because after each author name there is a variable for author separator
            }%  END DO
            \ifthenelse{\(\value{COUNT@cptBiographies}=\value{COUNT@articleBiographyNumber}\) \and
                     \(\value{COUNT@authorNum}=\value{COUNT@articleAuthorNumber}\)}%
            {%  THEN
                % all is fine: there is the same number of author and of biographies
            }{% ELSE
                \newline\textcolor{red}{!!! The number of biographies is different of the number of authors !!!!}
            }
        }{% ELSE
%            \par\textcolor{red}{!!! No biography defined !!!!}
        }
    \endgroup
}


%==============================================================
% article addresses list ======================================
%==============================================================

% -------------------------------------------------------------
% contains the address number. The value 0 means that no address
% has been defined
% -------------------------------------------------------------

\newcounter{COUNT@articleAddressNumber}
\setcounter{COUNT@articleAddressNumber}{0}

% -------------------------------------------------------------
% this command must be called as many times as address number.
% Contrary to authors, address is automatically numbered.
% #1: address of an author(s group)
% Output: commands named \VAR@articleAddressI, \VAR@articleAuthorII, \VAR@articleAuthorIII...
% containing respectively the first author, the string ', ', the second author...
% -------------------------------------------------------------

\newcommand{\address}[1]{%
    \stepcounter{COUNT@articleAddressNumber}
    \expandafter\newcommand\csname VAR@articleAddress\Roman{COUNT@articleAddressNumber}\endcsname{#1}
}


% -------------------------------------------------------------
% addresses list writing command used by \maketitle
% -------------------------------------------------------------

\newcommand{\WRITE@articleAddresses}{%
    \begingroup
        \setlength{\parindent}{0pt}
        \setlength{\parsep}{0pt plus 1pt minus 1pt}
        \setlength{\parskip}{0pt plus 1pt minus 1pt}
        \normalsize\em    % \fontsize{10}{12}\selectfont
        \raggedright
        \ifthenelse{\value{COUNT@articleAddressNumber}>0}%
        {%  THEN
            \ifthenelse{\value{COUNT@articleAddressNumber}=1}%
            {%  THEN no number before address
                \par\csname VAR@articleAddressI\endcsname\\[3pt]
                \csname VAR@articleEmailI\endcsname
            }{% ELSE each address is numbered
                \newcounter{COUNT@cptAddresses}%
                \setcounter{COUNT@cptAddresses}{0}%
                \begin{list}%
                        {\arabic{COUNT@cptAddresses}.\hfill}%       SEE The \LaTeX\ Companion, pp.~61--62
                        {\setlength{\itemsep}{6pt}%                 vertical space between the different items
                         \setlength{\parsep}{0pt plus 1pt minus 1pt}
                         \setlength{\labelwidth}{10pt plus 1fil}%   width of the label box
                         \setlength{\labelsep}{0pt}%                space between label box and first line of item
                         \setlength{\leftmargin}{\labelwidth}%      space between left margin and the text of list
                        }
                \whiledo{\value{COUNT@cptAddresses} < \value{COUNT@articleAddressNumber}}%
                {%  DO
                    \stepcounter{COUNT@cptAddresses}%
                    \item
                    \csname VAR@articleAddress\Roman{COUNT@cptAddresses}\endcsname\\[1pt]
                    \csname VAR@articleEmail\Roman{COUNT@cptAddresses}\endcsname
                }%  END DO
                \end{list}
            }% end if
        }{% ELSE
            \par\textcolor{red}{!!! No address defined !!!!}
        }
        % new empty line (6pt)
        \vspace{\baselineskip}
    \endgroup
}


%==============================================================
% article abstract & rsum ===================================
%==============================================================

% -------------------------------------------------------------
% for every value of \boolean{BOOL@journalInEnglishOnly}
% English abstract is always defined
% -------------------------------------------------------------

\newboolean{BOOL@articleAbstractDefined}

\renewcommand{\abstract}[1]{%
    \newcommand{\VAR@articleAbstract}{#1}
    \setboolean{BOOL@articleAbstractDefined}{true}
}

% -------------------------------------------------------------
% French abstract (rsum) is only defined when
% \boolean{BOOL@journalInEnglishOnly} is false (normal case)
% -------------------------------------------------------------

\newboolean{BOOL@articleResumeDefined}

\ifthenelse{\not\boolean{BOOL@journalInEnglishOnly}}%
{%  THEN
    \newcommand{\resume}[1]{%
        \newcommand{\VAR@articleResume}{#1}
        \setboolean{BOOL@articleResumeDefined}{true}
    }
}{% ELSE
}

% -------------------------------------------------------------
% abstract (and rsum) writing command (used by \maketitle)
% -------------------------------------------------------------

%%% Algorithm:
%%% ----------
%%% IF abstract is english only
%%% THEN write english abstract only
%%% ELSE
%%%     IF English option is defined
%%%     THEN write English astract and then French rsum
%%%     ELSE write French rsum and then English abstract

\newcommand{\WRITE@journalAbstractResume}{%
    \begingroup
        \setlength{\parindent}{0pt}
        \setlength{\parsep}{6pt plus 1pt minus 1pt}
        %   IF abstract is special
        \ifthenelse{\boolean{BOOL@journalInEnglishOnly}}%
        {%  THEN write english abstract only
            \ifthenelse{\boolean{BOOL@articleAbstractDefined}}%
            {%  THEN
                {\scriptsize\sc\em ABSTRACT.\ }%
                {\small\it\VAR@articleAbstract}\\[3pt]%
            }{% ELSE
                \textcolor{red}{{\small\it !!!! Abstract undefined !!!!}}%
            }%
        }{% ELSE abstract is not only in English but also in French
            \ifthenelse{\boolean{BOOL@articleAbstractDefined}\and\boolean{BOOL@articleResumeDefined}}%
            {%  THEN
                %   IF English option is defined
                \ifthenelse{\boolean{BOOL@englishEnabled}}%
                {%  THEN write English astract and then French rsum
                    {\scriptsize\sc\em R\'ESUM\'E.\ }%
                    {\small\it\sloppy\VAR@articleResume}\\[3pt]%
                    {\scriptsize\sc\em ABSTRACT.\ }%
                    {\small\it\sloppy\VAR@articleAbstract}%
                    
                }{% ELSE write French rsum and then English abstract
                    {\scriptsize\sc\em R\'ESUM\'E.\ }%
                    {\small\it\sloppy\VAR@articleResume}\\[3pt]%
                    {\scriptsize\sc\em ABSTRACT.\ }%
                    {\small\it\sloppy\VAR@articleAbstract}%
                }%
            }{% ELSE
                \par\textcolor{red}{{\small\it !!!! Abstract AND Rsum must be defined but at least one or the other is missing !!!!}}%
            }%
        }%
    \endgroup
}

%==============================================================
% article keywords & mots-cls ================================
%==============================================================

% -------------------------------------------------------------
% for every value of \boolean{BOOL@journalInEnglishOnly}
% English keywords are always defined
% -------------------------------------------------------------

\newboolean{BOOL@articleKeywordsDefined}

\newcommand{\keywords}[1]{%
    \newcommand{\VAR@articleKeywords}{#1}
    \setboolean{BOOL@articleKeywordsDefined}{true}
}

% -------------------------------------------------------------
% French keywords (mots-cls) are only defined when
% \boolean{BOOL@journalInEnglishOnly} is false (normal case)
% -------------------------------------------------------------

\newboolean{BOOL@articleMotsClesDefined}

\ifthenelse{\not\boolean{BOOL@journalInEnglishOnly}}%
{%  THEN
    \newcommand{\motscles}[1]{%
        \newcommand{\VAR@articleMotsCles}{#1}
        \setboolean{BOOL@articleMotsClesDefined}{true}
    }
}{% ELSE
}

% -------------------------------------------------------------
% keywords (and mots-cls) writing command (used by \maketitle)
% -------------------------------------------------------------

%%% Algorithm:
%%% ----------
%%% IF keywords are special
%%% THEN write english keywords only
%%% ELSE
%%%     IF English option is defined
%%%     THEN write English keywords and then French mots-cls
%%%     ELSE write French mots-cls and then English keywords

\newcommand{\WRITE@journalKeywordsMotsCles}{%
    \begingroup
        \setlength{\parindent}{0pt}
        \setlength{\parsep}{0pt plus 1pt minus 1pt}
        %   IF keywords are only written in English
        \ifthenelse{\boolean{BOOL@journalInEnglishOnly}}%
        {%  THEN write english keywords only
            \ifthenelse{\boolean{BOOL@articleKeywordsDefined}}%
            {%  THEN
                {\scriptsize\sc\em KEYWORDS:\ }%
                {\small\it\VAR@articleKeywords}\\[0pt]%
            }{% ELSE
                \textcolor{red}{{\small\it !!!! Keywords undefined !!!!}}%
            }%
        }{% ELSE
            \ifthenelse{\boolean{BOOL@articleKeywordsDefined}\and\boolean{BOOL@articleMotsClesDefined}}%
            {%  THEN
                %   IF English option is defined
                \ifthenelse{\boolean{BOOL@englishEnabled}}%
                {%  THEN write English astract and then French mots-cls
                    {\scriptsize\sc\em MOTS-CL\'ES~:\ }%
                    {\small\it\VAR@articleMotsCles}\\[0pt]%
                    {\scriptsize\sc\em KEYWORDS:\ }%
                    {\small\it\VAR@articleKeywords}\\[0pt]%
                }{% ELSE write French mots-cls and then English keywords
                    {\scriptsize\sc\em MOTS-CL\'ES~:\ }%
                    {\small\it\VAR@articleMotsCles}\\[0pt]%
                    {\scriptsize\sc\em KEYWORDS:\ }%
                    {\small\it\VAR@articleKeywords}\\[0pt]%
                }%
            }{% ELSE
                \par\textcolor{red}{{\small\it !!!! Keywords AND Mots-Cls must be defined but at least one or the other is missing !!!!}}%
            }%
        }%
    \endgroup
}

%==============================================================
% article page numbers ========================================
%==============================================================


% -------------------------------------------------------------
% article first page number
% -------------------------------------------------------------

\newcounter{COUNT@articleFirstPage}

% default value = 1
\setcounter{COUNT@articleFirstPage}{1}

% this value can be updated by author
\newcommand{\firstpagenumber}[1]{%
    \setcounter{COUNT@articleFirstPage}{#1}
    \setcounter{page}{#1}
}

% -------------------------------------------------------------
% article last page number
% -------------------------------------------------------------

% article last page
\newcommand{\VAR@articleLastPage}{\pageref{LABEL@articleLastPage}}

\AtEndDocument{%
    \label{LABEL@articleLastPage}%
}

% -------------------------------------------------------------
% write a label before the pages interval
% (used in first page footer)
% -------------------------------------------------------------

\newcommand{\WRITE@issuePagesLabel}{%
    \ifthenelse{\boolean{BOOL@journalHasEnglishTitleDefined}}%
    {%  THEN
        \ifthenelse{\boolean{BOOL@journalHasEnglishTitle}}%
        {%  THEN
            pages\
        }{% ELSE
            pages\
        }%
    }{% ELSE
        \textcolor{red}{!!!! Journal language undefined !!!!}
    }%
}

% -------------------------------------------------------------
% write the pages interval iff it has been defined
% (used in DOI and in first page footer)
% -------------------------------------------------------------

\newcommand{\WRITE@issuePagesInterval}{%
    \ifthenelse{\boolean{BOOL@issueNumberDefined}}%
    {%  THEN
        \ifthenelse{\boolean{BOOL@journalHasEnglishTitleDefined}}%
        {%  THEN
            \ifthenelse{\boolean{BOOL@journalHasEnglishTitle}}%
            {%  THEN
                \arabic{COUNT@articleFirstPage}--\VAR@articleLastPage%
            }{% ELSE
                \arabic{COUNT@articleFirstPage}-\VAR@articleLastPage%
            }%
        }{% ELSE
            \textcolor{red}{!!!! Journal language undefined !!!!}
        }%
    }{% ELSE
        \textcolor{red}{!!!! Issue number undefined !!!!}
    }%
}

%==============================================================
%==============================================================
% FIRST PAGE ==================================================
%==============================================================
%==============================================================


%==============================================================
% \maketitle command ==========================================
%==============================================================

\renewcommand{\maketitle}{%
    % default header and footer selection
    % (MUST be placed after its definition and after definition of BOOL@issueTitleDefined)
    \pagestyle{articleOtherpages}%
    \WRITE@articleTitle
    \thispagestyle{articleFirstPage}%
    \WRITE@articleSubTitle
    \vspace{-0.20cm}
    \WRITE@articleAuthors
    \vspace{-0.20cm}
    \WRITE@articleAddresses
    \hrule\strut\\[-4pt]
    \WRITE@journalAbstractResume
    \WRITE@journalKeywordsMotsCles
    \hrule\strut\\[-4pt]
    \normalfont\normalsize
    \setlength{\parindent}{5mm}
    \setlength{\parskip}{6pt}
}

%==============================================================
%==============================================================
% SECTIONS FORMATS ============================================
%==============================================================
%==============================================================

%%% Only four levels are avalaible
\setcounter{secnumdepth}{5}

%%% if a title is over several lines, there is no indentation
%%% after a line feed
\def\@hangfrom#1{%
       \setbox\@tempboxa\hbox{{#1}}%
       \hangindent \wd\@tempboxa\noindent\box\@tempboxa %% ORIGINAL de latex.ltx
       % \hangindent \wd 0 \noindent\box\@tempboxa %% old version of HERMES style
}

%%% Disable single lines at the start of a paragraph
\clubpenalty = 10000

%%% Disable single lines at the end of a paragraph
\widowpenalty = 10000
\displaywidowpenalty = 10000


%==============================================================
% Sections numbering ==========================================
%==============================================================

\renewcommand{\thesection}{\arabic{section}}
\renewcommand{\thesubsection}{\thesection.\arabic{subsection}}
\renewcommand{\thesubsubsection}{\thesubsection.\arabic{subsubsection}}
\renewcommand{\theparagraph}{\thesubsubsection.\arabic{paragraph}}
\renewcommand{\thesubparagraph}{}

%==============================================================
% section command redefinition ================================
%==============================================================

%%% beforeskip = 18pt, afterskip = 12pt
\newlength{\LEN@beforeSection}
\newlength{\LEN@afterSection}

\renewcommand{\section}{%
    %%% we must take away the parskip value to the skips values
    \setlength{\LEN@beforeSection}{-\parskip}
    \addtolength{\LEN@beforeSection}{18pt}
    \setlength{\LEN@afterSection}{-\parskip}
    \addtolength{\LEN@afterSection}{12pt}
    \renewcommand{\@seccntformat}[1]{\thesection.\hspace{0.5em}}%
    \@startsection{section}%        nom de l'inter
        {1}%                        niveau de l'inter
        {0pt}%                      l'indentation du titre et du texte suivant
        {\the\LEN@beforeSection plus 2pt minus 2pt}%  beforeskip
        {\the\LEN@afterSection plus 1pt minus 1 pt}%  afterskip
        {\normalfont\bfseries\raggedright}%    style
}


%==============================================================
% section reference command ===================================
%==============================================================

\ifthenelse{\boolean{BOOL@englishEnabled}}%
    {%  THEN
        \newcommand{\sectionref}[1]{Section~\ref{#1}}
    }{% ELSE
        \newcommand{\sectionref}[1]{section~\ref{#1}}
    }%


%==============================================================
% subsection command redefinition =============================
%==============================================================

%%% beforeskip = 18pt, afterskip = 12pt
\newlength{\LEN@beforeSubSection}
\newlength{\LEN@afterSubSection}

\renewcommand{\subsection}{%
    %%% we must take away the parskip value to the skips values
    \setlength{\LEN@beforeSubSection}{-\parskip}
    \addtolength{\LEN@beforeSubSection}{18pt}
    \setlength{\LEN@afterSubSection}{-\parskip}
    \addtolength{\LEN@afterSubSection}{12pt}
    \renewcommand{\@seccntformat}[1]{{\normalfont\bfseries\itshape\thesubsection.\hspace{0.5em}}}%
    \@startsection%
        {subsection}%                       nom de l'inter
        {2}%                                niveau de l'inter
        {0pt}%                              l'indentation du titre et du texte suivant
        {\the\LEN@beforeSubSection plus 2 pt minus 2pt}%        beforeskip
        {\the\LEN@afterSubSection plus 1pt minus 1pt}%          afterskip (0pt  remove the line feed)
        {\normalfont\bfseries\itshape\raggedright}%    style
}

%==============================================================
% subsubsection command redefinition ==========================
%==============================================================

%%% beforeskip = 6pt, afterskip = 6pt
\newlength{\LEN@beforeSubSubSection}
\newlength{\LEN@afterSubSubSection}

\renewcommand{\subsubsection}{%
    %%% we must take away the parskip value to the skips values
    \setlength{\LEN@beforeSubSubSection}{-\parskip+6pt}
    \addtolength{\LEN@beforeSubSubSection}{6.01pt}
    \setlength{\LEN@afterSubSubSection}{-\parskip}
    \addtolength{\LEN@afterSubSubSection}{6.01pt}
    \renewcommand{\@seccntformat}[1]{{\normalsize\normalfont\itshape\thesubsubsection.\hspace{0.5em}}}%
    \@startsection%
        {subsubsection}%            nom de l'inter
        {3}%                        niveau de l'inter
        {0mm}%                      l'indentation du titre et du texte suivant
        {\the\LEN@beforeSubSubSection plus 1 pt minus 1pt}%        beforeskip
        {\the\LEN@afterSubSubSection plus 1pt minus 1pt}%          afterskip (0pt  remove the line feed)
        {\normalfont\normalsize\itshape\raggedright}%     style
}

%==============================================================
% paragraph command redefinition ==============================
%==============================================================

%%% beforeskip = 6pt, afterskip = 6pt
\newlength{\LEN@beforeParagraph}
\newlength{\LEN@afterParagraph}

\renewcommand{\paragraph}{%
    %%% we must take away the parskip value to the skips values
    \setlength{\LEN@beforeParagraph}{-\parskip+6pt}
    \addtolength{\LEN@beforeParagraph}{6.01pt}
    \setlength{\LEN@afterParagraph}{-\parskip}
    \addtolength{\LEN@afterParagraph}{6.01pt}
    \renewcommand{\@seccntformat}[1]{{\normalsize\normalfont\theparagraph.\hspace{0.5em}}}%
    \@startsection%
        {paragraph}%                nom de l'inter
        {4}%                        niveau de l'inter
        {0mm}%                      l'indentation du titre et du texte suivant
        {\the\LEN@beforeParagraph plus 1pt minus 1 pt}%  beforeskip
        {\the\LEN@afterParagraph plus 1pt minus 1pt}%    afterskip  (0pt remove the line feed)
        {\normalfont\raggedright}%             style
}

%==============================================================
% subparagraph command redefinition ===========================
%==============================================================

%%% beforeskip=\parskip, afterskip=1em horizontal
\renewcommand{\subparagraph}{%
    \renewcommand{\@seccntformat}[1]{}%
        \@startsection%
        {subparagraph}%             nom de l'inter
        {5}%                        niveau de l'inter
        {0cm}%                      l'indentation du titre et du texte suivant
        {0pt plus 1pt minus 1 pt}%  beforeskip
        {-1em}%                     afterskip  (0pt remove the line feed)
        {\normalfont\scshape\raggedright}%     style
}


%==============================================================
% appendix commands redefinition ===========================
%==============================================================

\renewcommand\appendix{\par
    \setcounter{section}{0}%
    \setcounter{subsection}{0}%
    \ifthenelse{\boolean{BOOL@englishEnabled}}%
        {%  THEN
            \gdef\thesection{Annex~\Alph{section}}%
        }{% ELSE
            \renewcommand{\thesection}{Annexe~\Alph{section}}
        }%
        \renewcommand{\thesubsection}{\Alph{section}.\arabic{subsection}}
}

\newcommand{\annex}{\appendix}

%==============================================================
% appendix commands reference =================================
%==============================================================

\ifthenelse{\boolean{BOOL@englishEnabled}}%
    {%  THEN
        \newcommand{\annexref}[1]{\ref{#1}}
    }{% ELSE
        \newcommand{\annexref}[1]{\ref{#1}}
    }%


%==============================================================
%==============================================================
% LIST ENVIRONMENTS ===========================================
%==============================================================
%==============================================================


%==============================================================
% itemize =====================================================
%==============================================================

% -------------------------------------------------------------
% itemize level counter
% -------------------------------------------------------------
% there is only 2 different levels. Thus the counter is either 1 or 2.
\newcounter{COUNT@currentListLevel}
\setcounter{COUNT@currentListLevel}{0}

% -------------------------------------------------------------
% itemize margins computation
% -------------------------------------------------------------
% See LaTeX companion 2nd Edition, p.\ 145
% After the end of the first line, the second line begins
%   at the left margin level. To do that, we construct a box
%   of the right width.
% STEP A
% For the first level of itemize,
%   the symbol is --
%   the distance between left margin and the symbol is 5mm
% For the second level of itemize,
%   the symbol is -
%   the distance between left margin and the symbol is 10mm
% => we add the distance between left margin and the width of the symbol
% STEP B : Finally, we add to the width of the box
%   the distance between the itemize symbol and the text
%
% #1: it is -- or - (depending on the level of the itemize)
\newcommand{\SET@itemizeIndent}[1]{%
    % horizontal spacing
    % ------------------
    \setlength{\leftmargin}{0pt}    % space between list and left margin
    \setlength{\rightmargin}{0pt}   % space between list and right margin
    \setlength{\listparindent}{0pt} % additional space before first lines of new paragraphs in a same item
    \setlength{\labelsep}{0.5em}    % space from first word of item to right side of label
    % STEP A : size of the label box:
    \settowidth{\labelwidth}{#1}%
    %  IF we are in first level of list
    \ifthenelse{\value{COUNT@currentListLevel} < 2}%
        {%  THEN
            \addtolength{\labelwidth}{5mm}%
        }{% ELSE
            \addtolength{\labelwidth}{10mm}%
        }
    % STEP B : if we add the 5mm (resp. 10mm) here, label will be raggedleft
    \setlength{\itemindent}{\labelwidth+\labelsep} %
    %
    % vertical spacing
    % ----------------
    \setlength{\topsep}{0pt}        % space between text and top of list
    \setlength{\partopsep}{3pt}     % additional space before list when list begins a new paragraph
    \setlength{\parsep}{3pt}        % space between paragraphs in the same item
    \setlength{\itemsep}{0pt}       % space between items
    %
    % penalitities
    \sloppy%
    \widowpenalty4000%              % single line at the page beginning
    \clubpenalty4000%               % single line at the page end
}

% -------------------------------------------------------------
% itemize environment
% -------------------------------------------------------------
% it is redefined at begin document by babel package. Thus:
% - STEP A:  we define a new environment
% - STEP B: we rename it as `itemize' at the begin of document
%
% STEP A:
\newenvironment{ENV@itemize}%
    {%  BEGIN PART
        \setlength{\parskip}{3pt}
        % IF we are entering in a list that have an imbrication level greater than 1
        \ifthenelse{\value{COUNT@currentListLevel} > 1}
            {%  THEN we generate an error
                \typeout{}
                \typeout{!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!}
                \typeout{!! ERROR: lists can only have two levels !!}
                \typeout{!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!}
                \@toodeep
            }{% ELSE
                % we increase the list level
                \stepcounter{COUNT@currentListLevel}
                \begin{list}%
                    {%  ARG 1 : the label used is \labelitemi or \labelitemii (depending on current list level)
                        \csname labelitem\roman{COUNT@currentListLevel}\endcsname
                    }{% ARG 2 : we set the margins and labelitemi(i)
                        % labels setting
                        \renewcommand{\labelitemi}{--}
                        \renewcommand{\labelitemii}{-}
                        %
                        % margins setting
                        \ifthenelse{\value{COUNT@currentListLevel} = 1}%
                            {%  THEN
                                \SET@itemizeIndent{\labelitemi}
                            }{% ELSE
                                \SET@itemizeIndent{\labelitemii}
                            }%
                    }% end of the arguments list
            }% of else
    }{% END PART
        \end{list}%
        \addtocounter{COUNT@currentListLevel}{-1}%
    }
%
% STEP B:
\AtBeginDocument{%
    \renewenvironment{itemize}{\begin{ENV@itemize}}{\end{ENV@itemize}}
}


%==============================================================
% enumerate ===================================================
%==============================================================

% enumerate uses the same level variable as itemize environment

\newenvironment{ENV@enumerate}%
    {%  BEGIN PART
        \setlength{\parskip}{3pt}
        % IF we are entering in a list that have an imbrication level greater than 1
        \ifthenelse{\value{COUNT@currentListLevel} > 1}
            {%  THEN we generate an error
                \typeout{}
                \typeout{!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!}
                \typeout{!! ERROR: lists can only have two levels !!}
                \typeout{!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!}
                \@toodeep
            }{% ELSE
                % we increase the list level
                \stepcounter{COUNT@currentListLevel}
                \begin{list}%
                    {%  ARG 1 : the label used is \labelenumi or \labelenumii (depending on current list level)
                        \csname labelenum\roman{COUNT@currentListLevel}\endcsname
                    }{% ARG 2 : we set the margins and labelitemi(i)
                        % we define which counter must be used
                        \usecounter{enum\roman{COUNT@currentListLevel}}
                        %
                        % labels setting
%                        \renewcommand{\theenumi}{\arabic{enumi}}%      default value
%                        \renewcommand{\labelenumi}{\theenumi.}%        default value
%                        \renewcommand{\theenumii}{\alph{enumii}}%      default value
                        \renewcommand{\labelenumii}{\theenumii)}
%                        \renewcommand{\p@enumii}{\theenumi.}% \ref{label} in a second level enumeration write \p@enumii\theenumii
                        %
                        % margins setting
                        \ifthenelse{\value{COUNT@currentListLevel} = 1}%
                            {%  THEN
                                \SET@itemizeIndent{\labelenumi}%    spaces are the same as those of itemize
                            }{% ELSE
                                \SET@itemizeIndent{\labelenumii}
                            }%
                    }% end of the arguments list
            }% of else
    }{% END PART
        \end{list}%
        \addtocounter{COUNT@currentListLevel}{-1}%
    }
%
% STEP B:
\AtBeginDocument{%
    \renewenvironment{enumerate}{\begin{ENV@enumerate}}{\end{ENV@enumerate}}
}



%==============================================================
%==============================================================
% INSERT COMMANDS =============================================
%==============================================================
%==============================================================


%==============================================================
% formulas ====================================================
%==============================================================

\setlength{\jot}{0.5\baselineskip}      % space between different lines of eqnarray
\setlength{\abovedisplayskip}{0mm}      % additional space before big formulas
\setlength{\abovedisplayshortskip}{0mm} % the same for short formulas
\setlength{\belowdisplayskip}{0mm}      % additional space after big formulas
\setlength{\belowdisplayshortskip}{0mm} % the same for short formulas


%==============================================================
% footnotes ===================================================
%==============================================================

\providecommand*{\dotFFN}{.}
\providecommand*{\kernFFN}{\kern 0.5em}
\footnotesep=8pt

\long\def\@makefntextFB#1{%
    \rule\z@\footnotesep
    \noindent\@thefnmark\dotFFN\kernFFN #1
}%

\setlength{\skip\footins}{7mm plus 2mm}

\renewcommand{\footnoterule}{\vspace*{-3pt}%
    \hrule width 2.5cm height 0.4pt \vspace*{3pt}}

\AtBeginDocument{\@ifpackageloaded{bigfoot}{}%
                  {% ELSE
                   \long\def\@makefntext#1{\@makefntextFB{#1}}%
                  }%
                }




%==============================================================
% \thanks command =============================================
%==============================================================

\let\oldFootnote\footnote

\newcommand{\EXPR@thanksMark}{\makebox[8pt]{\textsuperscript{\thefootnote}}}

\renewcommand{\thanks}[1]{%
%    \addtolength{\skip\footins}{6pt}% = 12pt = 1 line between the rule
%%
%    \renewcommand{\footnoterule}{%
%    % must have a virtual total height = 0 (cf. Latex Companion p. 72)
%    \par\vspace*{-12.3pt}% total height
%    \noindent\rule{2.5cm}{0.3pt}\vspace*{6pt} % => total height 9.3pt
%                                              % between rule and footnote text: 6pt
%    }%
%%
%    % space between each footnote
%    \setlength{\footnotesep}{18pt}%
%%
    % redefinition de \thefootnote
    \renewcommand{\thefootnote}{$\star$}%
%
    % dfinition de la footnote mark
    \ifthenelse{\boolean{BOOL@englishEnabled}}%
    {%  THEN
        \providecommand{\EXPR@footnoteMark}{\unskip\kern -0.2em\mbox{\textsuperscript{\thefootnote}}}%
    }{% ELSE
        \providecommand{\EXPR@footnoteMark}{\unskip\kern -0.1em\mbox{\textsuperscript{\thefootnote}}}%
    }
%
    % redefinition of the footnote mark in the text
    \renewcommand{\@makefnmark}{\EXPR@footnoteMark}%
%
    % redefinition of the footnote itself
    \renewcommand{\@makefntext}[1]{\thefootnote.~#1}%
%
    \oldFootnote{#1}%
    % remise  zro du compteur
    \setcounter{footnote}{0}%
}


%==============================================================
% acknowledgements ============================================
%==============================================================

\newcommand{\acknowledgements}[1]{%
    \ifthenelse{\boolean{BOOL@englishEnabled}}%
        {%  THEN
            \newcommand{\acknowledgementsname}{Acknowledgements}%
        }{% ELSE
            \newcommand{\acknowledgementsname}{Remerciements}%
        }%
    \paragraph*{\emph{\acknowledgementsname}}
    \newlength{\ident@acknowledgements}%
    \setlength{\ident@acknowledgements}{\textwidth-0.3cm}%
    \noindent%
    \parbox{0.3cm}{\strut}%
    \parbox{\the\ident@acknowledgements}{\normalfont\normalsize\itshape #1}%
}

%==============================================================
%==============================================================
% MATHEMATICAL ENVIRONMENTS ===================================
%==============================================================
%==============================================================


%==============================================================
% counter and fonts ===========================================
%==============================================================


% -------------------------------------------------------------
% environments counter (the same for all environments)
% -------------------------------------------------------------
\newcounter{COUNT@theorem}
\setcounter{COUNT@theorem}{0}

% -------------------------------------------------------------
% theorems labels font
% -------------------------------------------------------------
\newcommand{\FONT@theoremLabel}{%
    \normalfont\normalsize\sc
}

% -------------------------------------------------------------
% font of label optionnal argument
% -------------------------------------------------------------
\newcommand{\FONT@optionnalTheoremLabel}{%
    \normalfont\normalsize
}

% -------------------------------------------------------------
% theorems body font
% -------------------------------------------------------------
\newcommand{\FONT@theoremBody}{%
    % IF the environment is boxed
    \ifthenelse{\boolean{BOOL@qedSymbolHasAValue}}%
        {% THEN no emphasis
            \normalfont\normalsize
        }{% ELSE emphase
            \normalfont\normalsize\em
        }%
}

%==============================================================
% QED symbols =================================================
%==============================================================

% -------------------------------------------------------------
% QED symbol value
% -------------------------------------------------------------
\newboolean{BOOL@qedSymbolHasAValue}         % false by default
\newcommand{\VAR@currentQedSymbolValue}{}

% -------------------------------------------------------------
% QED symbol update
% -------------------------------------------------------------
\newcommand{\SET@currentQedSymbolValue}[1]{%
    \ifthenelse{\equal{#1}{NIL}}%
        {%  THEN there is no symbol
            \renewcommand{\VAR@currentQedSymbolValue}{}%
            \setboolean{BOOL@qedSymbolHasAValue}{false}%
        }{% ELSE save the new symbol
            \renewcommand{\VAR@currentQedSymbolValue}{#1}%
            \setboolean{BOOL@qedSymbolHasAValue}{true}%
        }%
}

% -------------------------------------------------------------
% QED symbol expression
% -------------------------------------------------------------
\newcommand{\EXPR@currentQedSymbol}{%
    \ifthenelse{\boolean{BOOL@qedSymbolHasAValue}}%
        {%  THEN write symbol at the end of the current line
            {\setlength{\parskip}{0cm}\hspace*{\fill}\nolinebreak[2]\hspace*{\fill}\VAR@currentQedSymbolValue}%
        }{% ELSE do nothing
        }%
}

% -------------------------------------------------------------
% manual QED symbol call
% -------------------------------------------------------------
% The QED symbol is normally called in \end{mathematicalEnvironment}
% but if the last line begins by a command \item (enumerate, description,
% or itemize environment) the QED symbol is not at the end of this line but
% at the end of the next line.
% For this reason, the author can call the QED symbol manually, at
% the end of the line beginning by \item. In this case, the QED symbol
% must not be writen in \end{mathematicalEnvironment}

% the following boolean is true iff the command \QED has been called
\newcounter{BOOL@manualQedCalled}
\setcounter{BOOL@manualQedCalled}{0}

\newcommand{\QED}{%
    \EXPR@currentQedSymbol%
    \setcounter{BOOL@manualQedCalled}{1}
    %\par\vspace{1mm}% correction of vertical space in itemize and enumerate environment
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\endinput
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
